Acpi Smo8800 Dell Driver For Mac

Acpi Smo8800 Dell Driver For Mac Average ratng: 4,3/5 9018 votes
2014-09-29 12:46:10 UTC

/bluetooth-peripheral-device-code-28-free-download.html. Re: acpi smo8800 1 Jump to solution Sorry for resurrecting this old thread but for anyone experiencing this issue the device in question is most likely an 'STMicroelectronics 3-Axis Digital Accelerometer' also known as a 'Free Fall Sensor'. Mcculloch pro mac 700 manual.

Signed-off-by: Pali Rohár <***@gmail.com>
  • Determine whether acpi smo8800 1 not your system is still covered under warranty Know what software is currently installed on your system Find compatible drivers and utilities for your product Provide you acpi smo8800 1 relevant articles and self-help topics Collect software usage data Dell offers a variety of Software applications designed to.
  • PATCH dell-smo8800: Add more acpi ids and change description of driver. tristate 'Dell Latitude freefall driver (ACPI SMO8800/SMO8810)'.

---
drivers/platform/x86/Kconfig 4 ++--
drivers/platform/x86/dell-smo8800.c 10 ++++++++--
2 files changed, 10 insertions(+), 4 deletions(-)
diff --git a/drivers/platform/x86/Kconfig b/drivers/platform/x86/Kconfig
index 3bbcbf1.ba9ee4f 100644
--- a/drivers/platform/x86/Kconfig
+++ b/drivers/platform/x86/KconfigAcpi Smo8800 Dell Driver For Mac
@@ -128,10 +128,10 @@ config DELL_WMI_AIO
be called dell-wmi-aio.
config DELL_SMO8800
- tristate 'Dell Latitude freefall driver (ACPI SMO8800/SMO8810)'
+ tristate 'Dell Latitude freefall driver (ACPI SMO88XX)'
depends on ACPI
---help---
- Say Y here if you want to support SMO8800/SMO8810 freefall device
+ Say Y here if you want to support SMO88XX freefall device
on Dell Latitude laptops.
To compile this driver as a module, choose M here: the module will
--
1.7.9.5
--
To unsubscribe from this list: send the line 'unsubscribe linux-kernel' in
the body of a message to ***@vger.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/
2014-09-29 12:46:10 UTC
Signed-off-by: Pali Rohár <***@gmail.com>
---
drivers/platform/x86/Kconfig 4 ++--
drivers/platform/x86/dell-smo8800.c 10 ++++++++--
2 files changed, 10 insertions(+), 4 deletions(-)
diff --git a/drivers/platform/x86/Kconfig b/drivers/platform/x86/Kconfig
index 3bbcbf1.ba9ee4f 100644
--- a/drivers/platform/x86/Kconfig
+++ b/drivers/platform/x86/Kconfig
@@ -128,10 +128,10 @@ config DELL_WMI_AIO
be called dell-wmi-aio.
config DELL_SMO8800
- tristate 'Dell Latitude freefall driver (ACPI SMO8800/SMO8810)'
+ tristate 'Dell Latitude freefall driver (ACPI SMO88XX)'
depends on ACPI
---help---
- Say Y here if you want to support SMO8800/SMO8810 freefall device
+ Say Y here if you want to support SMO88XX freefall deviceAcpi Smo8800 Dell Driver For Mac
on Dell Latitude laptops.
To compile this driver as a module, choose M here: the module will
diff --git a/drivers/platform/x86/dell-smo8800.c b/drivers/platform/x86/dell-smo8800.c
index a653716.0aec4fd 100644
--- a/drivers/platform/x86/dell-smo8800.c
+++ b/drivers/platform/x86/dell-smo8800.c
@@ -1,5 +1,5 @@
/*
* dell-smo8800.c - Dell Latitude ACPI SMO8800/SMO8810 freefall sensor driver
*
* Copyright (C) 2012 Sonal Santan <***@gmail.com>
* Copyright (C) 2014 Pali Rohár <***@gmail.com>
@@ -209,7 +209,13 @@ static int smo8800_remove(struct acpi_device *device)
static const struct acpi_device_id smo8800_ids[] = {
{ 'SMO8800', 0 },
+ { 'SMO8801', 0 },
{ 'SMO8810', 0 },
+ { 'SMO8811', 0 },
+ { 'SMO8820', 0 },
+ { 'SMO8821', 0 },
+ { 'SMO8830', 0 },
+ { 'SMO8831', 0 },
{ ', 0 },
};
@@ -228,6 +234,6 @@ static struct acpi_driver smo8800_driver = {
module_acpi_driver(smo8800_driver);

-MODULE_DESCRIPTION('Dell Latitude freefall driver (ACPI SMO8800/SMO8810)');
+MODULE_DESCRIPTION('Dell Latitude freefall driver (ACPI SMO88XX)');
MODULE_LICENSE('GPL');
MODULE_AUTHOR('Sonal Santan, Pali Rohár');
@@ -1,5 +1,5 @@
/*
- * dell-smo8800.c - Dell Latitude ACPI SMO8800/SMO8810 freefall sensor driver
+ * dell-smo8800.c - Dell Latitude ACPI SMO88XX freefall sensor driver
*
* Copyright (C) 2012 Sonal Santan <***@gmail.com>
diff --git a/drivers/platform/x86/dell-smo8800.c b/drivers/platform/x86/dell-smo8800.c
index a653716.0aec4fd 100644
--- a/drivers/platform/x86/dell-smo8800.c
+++ b/drivers/platform/x86/dell-smo8800.c
@@ -1,5 +1,5 @@
/*
* dell-smo8800.c - Dell Latitude ACPI SMO8800/SMO8810 freefall sensor driver
*
* Copyright (C) 2012 Sonal Santan <***@gmail.com>
* Copyright (C) 2014 Pali Rohár <***@gmail.com>
@@ -209,7 +209,13 @@ static int smo8800_remove(struct acpi_device *device)
static const struct acpi_device_id smo8800_ids[] = {
{ 'SMO8800', 0 },
+ { 'SMO8801', 0 },
{ 'SMO8810', 0 },
+ { 'SMO8811', 0 },
+ { 'SMO8820', 0 },
+ { 'SMO8821', 0 },
+ { 'SMO8830', 0 },

Acpi Smo8800 Dell Driver For Macbook

+ { 'SMO8831', 0 },
{ ', 0 },
};
@@ -228,6 +234,6 @@ static struct acpi_driver smo8800_driver = {

Acpi Smo8800


module_acpi_driver(smo8800_driver);
-MODULE_DESCRIPTION('Dell Latitude freefall driver (ACPI SMO8800/SMO8810)');

Acpi Smo8800 Dell Driver For Macbook Air


+MODULE_DESCRIPTION('Dell Latitude freefall driver (ACPI SMO88XX)');
MODULE_LICENSE('GPL');
MODULE_AUTHOR('Sonal Santan, Pali Rohár');
@@ -1,5 +1,5 @@
/*
- * dell-smo8800.c - Dell Latitude ACPI SMO8800/SMO8810 freefall sensor driver
+ * dell-smo8800.c - Dell Latitude ACPI SMO88XX freefall sensor driver
*
* Copyright (C) 2012 Sonal Santan <***@gmail.com>
--
1.7.9.5
--
To unsubscribe from this list: send the line 'unsubscribe linux-kernel' in
the body of a message to ***@vger.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/